# SPDX-FileCopyrightText: 2017-present linuxdaemon <linuxdaemon.irc@gmail.com>
#
# SPDX-License-Identifier: MIT

"""IRC parser and utility library."""

from irclib._version import (
    __version__,
    __version_tuple__,
    version,
    version_tuple,
)

__all__ = ["__version__", "__version_tuple__", "version", "version_tuple"]



# SPDX-FileCopyrightText: 2017-present linuxdaemon <linuxdaemon.irc@gmail.com>
#
# SPDX-License-Identifier: MIT

"""Library exceptions."""

__all__ = ("ParseError",)


class ParseError(ValueError):
    """An exception representing some error during parsing."""



# SPDX-FileCopyrightText: 2017-present linuxdaemon <linuxdaemon.irc@gmail.com>
#
# SPDX-License-Identifier: MIT

"""IRC utils."""

from irclib.util import commands, compare, frozendict, numerics, string

__all__ = ("commands", "compare", "frozendict", "numerics", "string")
